@@ -13,7 +13,7 @@ from typing import Iterable, Optional, Tuple, Union
 from xml.dom.minidom import parseString
 from xml.etree.ElementTree import Element, SubElement, tostring
 from .osutil import get_lib_extension, get_platform
-from .fmi3slave import FMI3_MODEL_OPTIONS, Fmi3Slave
+from .fmi3slave import FMI3_MODEL_OPTIONS, Fmi3Slave, Fmi3SlaveBase
 
 FilePath = Union[str, Path]
 HERE = Path(__file__).parent
@@ -24,7 +24,7 @@ logger = logging.getLogger(__name__)
 def get_class_name(file_name: Path) -> str:
     with open(str(file_name), 'r') as file:
         data = file.read()
-        return re.search(r'class (\w+)\(\s*Fmi3Slave\s*\)\s*:', data).group(1)
+        return re.search(r'class (\w+)\(([^)]*\bFmi3Slave(?:Base)?\b[^)]*)\)\s*:', data).group(1)
 
 
 def get_model_description(filepath: Path, module_name: str) -> Tuple[str, Element]:
@@ -50,9 +50,9 @@ def get_model_description(filepath: Path, module_name: str) -> Tuple[str, Elemen
     finally:
         sys.path.remove(str(filepath.parent))  # remove inserted temporary path
 
-    if not isinstance(instance, Fmi3Slave):
+    if not isinstance(instance, Fmi3SlaveBase):
         raise TypeError(
-            f"The provided class '{class_name}' does not inherit from {Fmi3Slave.__qualname__}"
+            f"The provided class '{class_name}' does not inherit from {Fmi3SlaveBase.__qualname__}"
         )
     # Produce the xml
     return instance.modelName, instance.to_xml()
@@ -66,7 +66,7 @@ class FmuBuilder:
         dest: FilePath = ".",
         project_files: Iterable[FilePath] = set(),
         documentation_folder: Optional[FilePath] = None,
-        terminals_folder: Optional[FilePath] = None,
+        terminals : Optional[FilePath] = None,
         **options,
     ) -> Path:
         script_file = Path(script_file)
@@ -87,11 +87,15 @@ class FmuBuilder:
                     f"The documentation folder does not exists {documentation_folder!s}"
                 )
         
-        if terminals_folder is not None:
-            terminals_folder = Path(terminals_folder)
-            if not terminals_folder.exists():
+        if terminals is not None:
+            terminals = Path(terminals)
+            if not terminals.exists():
                 raise ValueError(
-                    f"The terminals folder does not exists {terminals_folder!s}"
+                    f"The specified terminalsAndIcons file does not exists {terminals!s}"
+                )
+            if not terminals.name == "terminalsAndIcons.xml":
+                raise ValueError(
+                    f"Incorrect terminal name {terminals!s}. Terminal file must be named terminalsAndIcons.xml"
                 )
 
         module_name = script_file.stem
@@ -134,9 +138,16 @@ class FmuBuilder:
 
             type_node = xml.find("CoSimulation")
             option_names = [opt.name for opt in FMI3_MODEL_OPTIONS]
-            for option, value in options.items():
-                if option in option_names:
-                    type_node.set(option, str(value).lower())
+            if type_node:
+                for option, value in options.items():
+                    if option in option_names:
+                        type_node.set(option, str(value).lower())
+
+            type_node = xml.find("ModelExchange")
+            if type_node:
+                for option, value in options.items():
+                    if option in option_names:
+                        type_node.set(option, str(value).lower())
 
             with zipfile.ZipFile(dest_file, "w") as zip_fmu:
 
@@ -186,12 +197,10 @@ class FmuBuilder:
                             relative_f = f.relative_to(documentation_folder)
                             zip_fmu.write(f, arcname=(documentation / relative_f))
 
-                if terminals_folder is not None:
-                    terminals = Path("terminalsAndIcons")
-                    for f in terminals_folder.rglob("*.xml"):
-                        if f.is_file():
-                            relative_f = f.relative_to(terminals_folder)
-                            zip_fmu.write(f, arcname=(terminals / relative_f))
+                if terminals is not None:
+                    terminalsFolder = Path("terminalsAndIcons")
+                    relative_f = terminals.relative_to(terminals.parent)
+                    zip_fmu.write(f, arcname=(terminalsFolder / relative_f))
                     
 
                 # Add the model description
@@ -233,8 +242,8 @@ def create_command_parser(parser: argparse.ArgumentParser):
 
     parser.add_argument(
         "--terminals",
-        dest="terminals_folder",
-        help="Folder containing terminals to include in the FMU.",
+        dest="terminals",
+        help="Terminals file (terminalsAndIcons.xml) to include in the FMU.",
         default=None
     )
 
